@@ -14,7 +14,7 @@ void c_opf_accuracy4label(int *argc, char **argv)
 	int i;
 	float *Acc = NULL;
 	FILE *f = NULL;
-	char fileName[256];
+	char fileName[4096];
 
 	Rprintf("\nReading data file ...");
 	
@@ -24,7 +24,7 @@ void c_opf_accuracy4label(int *argc, char **argv)
 
 	Rprintf("\nReading output file ...");
 	
-	sprintf(fileName, "%s.out", argv[1]);
+	snprintf(fileName, 4096, "%s.out", argv[1]);
 	f = fopen(fileName, "r");
 	if (!f)
 	{
@@ -52,7 +52,7 @@ void c_opf_accuracy4label(int *argc, char **argv)
 
 	Rprintf("\nWriting accuracy in output file ...");
 	
-	sprintf(fileName, "%s.acc", argv[1]);
+	snprintf(fileName, 4096, "%s.acc", argv[1]);
 	f = fopen(fileName, "a");
 	for (i = 1; i <= g->nlabels; i++)
 	{
