@@ -14,7 +14,7 @@ void c_opf_train(int *argc, char **argv)
 	}
 
 	int n, i;
-	char fileName[256];
+	char fileName[4096];
 	FILE *f = NULL;
 	timer tic, toc;
 	float time;
@@ -42,14 +42,14 @@ void c_opf_train(int *argc, char **argv)
 
 	Rprintf("\nWriting classifier's model file ...");
 	
-	sprintf(fileName, "%s.classifier.opf", argv[1]);
+	snprintf(fileName, 4096, "%s.classifier.opf", argv[1]);
 	opf_WriteModelFile(g, fileName);
 	Rprintf(" OK");
 	
 
 	Rprintf("\nWriting output file ...");
 	
-	sprintf(fileName, "%s.out", argv[1]);
+	snprintf(fileName, 4096, "%s.out", argv[1]);
 	opf_WriteOutputFile(g, fileName);
 	Rprintf(" OK");
 	
@@ -69,7 +69,7 @@ void c_opf_train(int *argc, char **argv)
 	Rprintf("\nTraining time: %f seconds\n", time);
 	
 
-	sprintf(fileName, "%s.time", argv[1]);
+	snprintf(fileName, 4096, "%s.time", argv[1]);
 	f = fopen(fileName, "a");
 	fprintf(f, "%f\n", time);
 	fclose(f);
